==> downloads.php?file=source%2Ftruecrypt-2.0-source-code.zip: TrueCrypt/Format/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Format.rc
//
#define IDS_CIPHER_TITLE                15
#define IDS_SIZE_TITLE                  16
#define IDS_MDCSHA_HELP0                17
#define IDS_MDCSHA_HELP1                18
#define IDS_MDCSHA_HELP2                19
#define IDS_MDCSHA_HELP3                20
#define IDS_NEXT                        21
#define IDS_FINISH                      22
#define IDS_OPEN_TITLE                  23
#define IDS_FILE_TITLE                  24
#define IDS_FILE_HELP0                  25
#define IDS_SIZE_PARTITION_HELP         26
#define IDS_FILE_HELP1                  27
#define IDS_FORMAT_ABORT                28
#define IDS_WARN_QUICK_FORMAT           29
#define IDS_FORMAT_TITLE                33
#define IDS_PASSWORD_TITLE              34
#define IDS_PREV                        42
#define IDS_SIZE_HELP0                  43
#define IDS_SIZE_HELP1                  44
#define IDS_FORMAT_HELP0                46
#define IDS_TITLE                       50
#define IDS_VOL_STATUS0                 51
#define IDS_VOL_STATUS1                 52
#define IDS_VOL_STATUS2                 53
#define IDS_VOL_NO_LABEL                54
#define IDS_VOL_LABEL                   55
#define IDS_FORMAT_HELP1                56
#define IDS_FORMAT_HELP2                57
#define IDS_READONLYPROMPT              58
#define IDS_CIPHER_NONE_HELP0           61
#define IDS_DISK_FREE_BYTES             63
#define IDS_DISK_FREE_KB                64
#define IDS_DISK_FREE_MB                65
#define IDS_CANNOT_CALC_SPACE           66
#define IDS_DEVICE_FREE_BYTES           67
#define IDS_DEVICE_FREE_KB              68
#define IDS_DEVICE_FREE_MB              69
#define IDS_DES_HELP0                   70
#define IDS_DES_HELP1                   71
#define IDS_BLOWFISH_HELP0              72
#define IDS_BLOWFISH_HELP1              73
#define IDS_IDEA_HELP0                  74
#define IDS_IDEA_HELP1                  75
#define IDS_AES_HELP0                   76
#define IDS_AES_HELP1                   77
#define IDS_TRIPLEDES_HELP0             82
#define IDS_TRIPLEDES_HELP1             83
#define IDS_CAST_HELP0                  84
#define IDS_CAST_HELP1                  85
#define IDS_DRIVE_TOO_BIG               86
#define IDS_EXT_PARTITION               87
#define IDS_CIPHER_TEST                 88
#define IDS_TESTS_PASSED                89
#define IDS_TESTS_FAILED                90
#define IDS_TEST_KEY_SIZE               91
#define IDS_TEST_PLAINTEXT_SIZE         92
#define IDS_TEST_CIPHERTEXT_SIZE        93
#define IDD_MKFS_DLG                    102
#define IDD_CIPHER_PAGE_DLG             112
#define IDD_SIZE_PAGE_DLG               113
#define IDD_PASSWORD_PAGE_DLG           114
#define IDD_FILE_PAGE_DLG               115
#define IDD_FORMAT_PAGE_DLG             116
#define IDD_VOLSTATS_DLG                117
#define IDB_TRUECRYPT                   122
#define IDD_CIPHER_TEST_DLG             145
#define IDC_KEY                         1001
#define IDC_PLAINTEXT                   1002
#define IDC_CIPHERTEXT                  1003
#define IDC_BOX_TITLE                   1009
#define IDC_POS_BOX                     1010
#define IDC_COMBO_BOX                   1011
#define IDC_BOX_HELP                    1013
#define IDC_PASSWORD                    1014
#define IDC_SPACE_LEFT                  1014
#define IDC_VERIFY                      1015
#define IDC_KB                          1017
#define IDC_NO_HISTORY                  1017
#define IDC_MB                          1018
#define IDC_PROGRESS_BAR                1019
#define IDC_STATS_BOX                   1021
#define IDC_CANCEL_BAR                  1022
#define IDC_SHA1                        1024
#define IDC_MD5                         1025
#define IDC_RIPEMD160                   1025
#define IDC_KEY_SALT                    1026
#define IDC_MD6                         1026
#define IDC_DISK_KEY                    1027
#define IDC_RANDOM_BYTES                1028
#define IDC_CIPHER_TEST                 1029
#define IDC_KEY_SIZE                    1032
#define IDC_PLAINTEXT_SIZE              1033
#define IDC_REDTICK                     1035
#define IDC_TESTS_MESSAGE               1036
#define IDC_QUICKFORMAT                 1037
#define IDC_BYTESWRITTEN                1038
#define IDC_STATIC9                     1039
#define IDC_WRITESPEED                  1039
#define IDC_BYTESWRITTEN3               1041
#define IDC_TIMEREMAIN                  1041
#define IDC_COMBO1                      1042
#define IDC_CLUSTERSIZE                 1042
#define IDC_SPIN1                       1043
#define IDC_RESET                       1104
#define IDC_AUTO                        1105
#define IDC_DECRYPT                     1112
#define IDC_SIZEBOX                     2014
#define IDC_BROWSE_FILES                2014
#define IDC_BROWSE_DEVICES              2017
#define IDC_NEXT                        11402
#define IDC_PREV                        11605

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        123
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1045
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> downloads.php?file=source%2Ftruecrypt-2.1a-source-code.zip: TrueCrypt/Format/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Format.rc
//
#define IDS_CIPHER_TITLE                15
#define IDS_SIZE_TITLE                  16
#define IDS_MDCSHA_HELP0                17
#define IDS_MDCSHA_HELP1                18
#define IDS_MDCSHA_HELP2                19
#define IDS_MDCSHA_HELP3                20
#define IDS_NEXT                        21
#define IDS_FINISH                      22
#define IDS_OPEN_TITLE                  23
#define IDS_FILE_TITLE                  24
#define IDS_FILE_HELP0                  25
#define IDS_SIZE_PARTITION_HELP         26
#define IDS_FILE_HELP1                  27
#define IDS_FORMAT_ABORT                28
#define IDS_WARN_QUICK_FORMAT           29
#define IDS_FORMAT_TITLE                33
#define IDS_PASSWORD_TITLE              34
#define IDS_PREV                        42
#define IDS_SIZE_HELP0                  43
#define IDS_SIZE_HELP1                  44
#define IDS_FORMAT_HELP0                46
#define IDS_TITLE                       50
#define IDS_FORMAT_HELP1                56
#define IDS_FORMAT_HELP2                57
#define IDS_READONLYPROMPT              58
#define IDS_CIPHER_NONE_HELP0           61
#define IDS_DISK_FREE_BYTES             63
#define IDS_DISK_FREE_KB                64
#define IDS_DISK_FREE_MB                65
#define IDS_CANNOT_CALC_SPACE           66
#define IDS_DEVICE_FREE_BYTES           67
#define IDS_DEVICE_FREE_KB              68
#define IDS_DEVICE_FREE_MB              69
#define IDS_DES_HELP0                   70
#define IDS_DES_HELP1                   71
#define IDS_BLOWFISH_HELP0              72
#define IDS_BLOWFISH_HELP1              73
#define IDS_AES_HELP0                   76
#define IDS_AES_HELP1                   77
#define IDS_TRIPLEDES_HELP0             82
#define IDS_TRIPLEDES_HELP1             83
#define IDS_CAST_HELP0                  84
#define IDS_CAST_HELP1                  85
#define IDS_EXT_PARTITION               87
#define IDS_CIPHER_TEST                 88
#define IDS_TESTS_PASSED                89
#define IDS_TESTS_FAILED                90
#define IDS_TEST_KEY_SIZE               91
#define IDS_TEST_PLAINTEXT_SIZE         92
#define IDS_TEST_CIPHERTEXT_SIZE        93
#define IDD_MKFS_DLG                    102
#define IDD_CIPHER_PAGE_DLG             112
#define IDD_SIZE_PAGE_DLG               113
#define IDD_PASSWORD_PAGE_DLG           114
#define IDD_FILE_PAGE_DLG               115
#define IDD_FORMAT_PAGE_DLG             116
#define IDD_VOLSTATS_DLG                117
#define IDB_TRUECRYPT                   122
#define IDD_CIPHER_TEST_DLG             145
#define IDC_KEY                         1001
#define IDC_PLAINTEXT                   1002
#define IDC_CIPHERTEXT                  1003
#define IDC_BOX_TITLE                   1009
#define IDC_POS_BOX                     1010
#define IDC_COMBO_BOX                   1011
#define IDC_BOX_HELP                    1013
#define IDC_PASSWORD                    1014
#define IDC_SPACE_LEFT                  1014
#define IDC_VERIFY                      1015
#define IDC_KB                          1017
#define IDC_NO_HISTORY                  1017
#define IDC_MB                          1018
#define IDC_PROGRESS_BAR                1019
#define IDC_STATS_BOX                   1021
#define IDC_CANCEL_BAR                  1022
#define IDC_SHA1                        1024
#define IDC_RIPEMD160                   1025
#define IDC_HEADER_KEY                  1026
#define IDC_DISK_KEY                    1027
#define IDC_RANDOM_BYTES                1028
#define IDC_CIPHER_TEST                 1029
#define IDC_KEY_SIZE                    1032
#define IDC_PLAINTEXT_SIZE              1033
#define IDC_REDTICK                     1035
#define IDC_TESTS_MESSAGE               1036
#define IDC_QUICKFORMAT                 1037
#define IDC_BYTESWRITTEN                1038
#define IDC_WRITESPEED                  1039
#define IDC_TIMEREMAIN                  1041
#define IDC_CLUSTERSIZE                 1042
#define IDC_SPIN1                       1043
#define IDC_FILESYS                     1043
#define IDC_SHOW_KEYS                   1049
#define IDC_RESET                       1104
#define IDC_AUTO                        1105
#define IDC_DECRYPT                     1112
#define IDC_SIZEBOX                     2014
#define IDC_BROWSE_FILES                2014
#define IDC_BROWSE_DEVICES              2017
#define IDC_NEXT                        11402
#define IDC_PREV                        11605

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        123
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1050
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
